"""
	Licensed Materials - Property of IBM Corp. 
IBM Rational Build Forge 
(c) Copyright IBM Corporation 2005, 2009. All Rights Reserved.   

U.S. Government Users Restricted Rights - Use, duplication or disclosure restricted by 
GSA ADP Schedule Contract with IBM Corp. 

	
	File name: installApp.py
	
	Installs an application into WebSphere Application Server
"""

import sys

"""
	Sets default values for specific options.
	
	If MapModulesToServers is not defined, it will be defined as 
	 .* .* WebSphere:cell=wp61_was70_nd,node=node01,server=standalone
	 or
	 .* .* WebSphere:cell=wp61_was70_nd,cluster=portal_cluster
	 
	If MapWebModToVH is not defined, it will be defined as
	.* .* default_host
"""
def _setDefaultOptions(options, optDict):
	if (options.find("-MapModulesToServers") == -1):
		## default this to -MapModulesToServers [[.* .* cluster/server]]
		if (optDict['scope'] == "cluster"):
			server = "WebSphere:cell=" + optDict['cell'] + ",cluster=" + optDict['scopename']
			options = options + "-MapModulesToServers " + " [[ .* .* " + server + " ]] "
		elif (optDict['scope'] == "server"):
			server = "WebSphere:cell=" + optDict['cell'] + ",node=" + optDict['node'] +",server="+ optDict['scopename']
			options = options + "-MapModulesToServers " + " [[ .* .* " + server + " ]] "
		#endIf
	if (options.find("-MapWebModToVH") == -1):
		## default this to -MapWebModToVH [[.* .* default_host]]
		options = options + "-MapWebModToVH [[ .* .* default_host ]] "
	return options
#endDef

optDict, args = SystemUtils.getopt( sys.argv, 'appProps:;appFile:;scope:;node:;cell:;scopename:;mode:' )

# parse the properties into props
props = SystemUtils.getPropertyDict( optDict['appProps'] )
if (not props.has_key("APP_NAME")):
	print "APP_NAME was not defined in " + optDict['appProps']
	sys.exit(-1)
else:
	appName =  props["APP_NAME"]		
#endIf 

warClassLoaderPolicy = None
if (props.has_key("WAR_CLASS_LOADER_POLICY")):
	warClassLoaderPolicy = props["WAR_CLASS_LOADER_POLICY"]		
#endIf 

classLoaderMode = None
if (props.has_key("CLASS_LOADER_MODE")):
	classLoaderMode = props["CLASS_LOADER_MODE"]		
#endIf 

if (not props.has_key("OPTIONS")):
	# options are not defined, so parse the config file for split options and create options string
	options = WasDeploy.createOptions(optDict['appProps'])
	options = _setDefaultOptions(options, optDict)
	print "OPTIONS after parsing " + optDict['appProps'] + "=" + options
else:
	print "OPTIONS is defined in " + optDict['appProps']
	options = props["OPTIONS"]		
#endIf 

if (optDict['scope'] == "cluster"):
	scopeArguments = '-cluster ' + optDict['scopename']
elif (optDict['scope'] == "server"):
	scopeArguments = '-node ' + optDict['node'] + ' -server ' + optDict['scopename']
else:
	## scope is cell, so options has to contain -MapModulesToServers or the modules will end up mapped to the dmgr server
	if (options.find("-MapModulesToServers") == -1):
		print "Warning: -MapModulesToServers is not defined in the options string."
		print "         Modules will be mapped to dmgr if this is a managed cell."
	#endIf
	scopeArguments = '-cell ' + optDict['scopename']
#endIf

WasDeploy.installApp( options, scopeArguments, optDict['appFile'], appName)
# check if we were successful
appExists = WasDeploy.checkIfAppExists(appName )
if (appExists):
	WasDeploy.postInstallConfig(appName, warClassLoaderPolicy, classLoaderMode )
else:
	print "Error: Failed to find application '" + str(appName) + "' in Application Server configuration."
	sys.exit(-1)
#endElse 

# save config
print "Saving Config..."
AdminConfig.save( )

